# lockfile
Создание файла блокировки, для предотвращения выполнения нескольких копий скрипта.

Использование
```
from lockfile import *

lock = lockfile('<PATH TO LOCKFILE>') #Определяем путь до файла блокировки
lock.create() #Создание файла блокировки
#Тело скрипта.\n
lock.delete # Удаление файла блокировки
```
